@@ -7,13 +7,16 @@ import (
 	"github.com/snyk/driftctl/test/acceptance"
 )
 
-func TestAcc_AwsIamPolicyAttachment_WithGroupsUsers(t *testing.T) {
+func TestAcc_Aws_IamPolicyAttachment_WithGroupsUsers(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.15.5",
 		Paths:            []string{"./testdata/acc/aws_iam_policy_attachment"},
 		Args:             []string{"scan", "--deep"},
 		Checks: []acceptance.AccCheck{
 			{
+				Env: map[string]string{
+					"AWS_REGION": "us-east-1",
+				},
 				Check: func(result *test.ScanResult, stdout string, err error) {
 					if err != nil {
 						t.Fatal(err)
